import { DialogService, LoadingService, Modal, ModalService, Select } from '@zeedhi/common';
import { InstanceService } from '@/services/InstanceService';
import { Config, Http, Metadata } from '@zeedhi/core';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { Utilities } from '@/services/Utilities';
import Messages from '@/services/Messages';
import { FileUpload } from '@/services/FileUpload';
import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { ZdFileInput } from '@zeedhi/vuetify';

export class DMGridTaskSoliController {
	private modalAddTaskS!: Modal;

	private nrsoliserv: string = '';

	public baseUrl: string = '';

	private cditemtrab: string = '';

	private nrTarefa: string = '';

	public taskResponse: string = '';

	public taskDescription: string = '';

	private indexGoogleDocsIds: any = {};

	public async addClickGridTaskSGridS() {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/Task/Soli/tabTaskSoli/gridTaskS/modalAddTaskS', true);
		this.modalAddTaskS.show();
	}

	public async addClickItemTaskSoli() {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/Task/Soli/tabTaskSoli/gridItemTaskS/modalAddItemTaskS', true);
		this.modalAddTaskS.show();
	}

	public async editEspecSoli() {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/Task/Soli/tabTaskSoli/gridItemTaskS/editEspecTaskS', true);
		this.modalAddTaskS.show();
	}

	public async addClickGridTaskActivity(params: any) {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/responseTaskS', true);
		LoadingService.show();
		try {
			console.log(this.modalAddTaskS);
			const taskActivityDetails = await Http.get('findActivityDetails', { params: { NRTAREFA: params.row.NRTAREFA, CDFILIAL: params.row.CDFILIAL, NRPLATIVTARE: params.row.NRPLATIVTARE } });
			this.taskDescription = taskActivityDetails.data.DESCRIPTION;
			this.taskResponse = taskActivityDetails.data.RESPONSE;
			LoadingService.hide();
			this.modalAddTaskS.show();
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public getColumnStyle(params: any) {
		let $color = 'pm-grid-color-black';
		if (params.row.IDSITATIVTAR === 'P') {
			$color = 'pm-grid-color-black';
			// ClWindowsText?
		} else if (params.row.IDSITATIVTAR === 'C' || params.row.IDSITATIVTAR === 'X') {
			$color = 'pm-grid-color-gray';
		} else if (params.row.IDSITATIVTAR === 'A') {
			$color = 'pm-grid-color-green';
		} else if (params.row.IDSITATIVTAR === 'I') {
			$color = 'pm-grid-color-navy';
		}
		if (params.row.DTFIPATIVTAR) {
			if (params.row.IDSITATIVTAR === 'I' || params.row.IDSITATIVTAR === 'P') {
				if (params.row.IS_DELAYED) {
					$color = 'pm-grid-color-red';
				}
			}
		}
		if (params.row.DTFIRATIVTAR && params.row.IDSITATIVTAR !== 'A' && params.row.IDSITATIVTAR !== 'C') {
			$color = 'pm-grid-color-blue';
		}
		return $color;
    }

	public async clickButtonSaveSpecificationTaskS() {
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		const namedoc = `${this.nrsoliserv}_${this.cditemtrab}`;
		const idGoogle = this.indexGoogleDocsIds[namedoc];
		if (idGoogle) {
			try {
				LoadingService.show();
				await Http.post('saveSpecificationSoliserv', {
					CDITEMTRAB: this.cditemtrab,
					NRSOLISERV: this.nrsoliserv,
					ID_GOOGLE: idGoogle,
				});
				delete this.indexGoogleDocsIds[namedoc];
				this.modalAddTaskS.hide();
				this.modalAddTaskS?.destroy();
				LoadingService.hide();
			} catch (e) {
				LoadingService.hide();
				DialogServiceCustom.showError(e);
			}
		} else {
			AlertServiceCustom.customErrorAlert(Messages.ERROR_FILE_TYPE);
		}
	}

	public async clickButtonCancelSpecificationTaskS(param: any) {
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		const namedoc = `${this.nrsoliserv}_${param.row.CDITEMTRAB}`;
		const idGoogle = this.indexGoogleDocsIds[namedoc];
		if (idGoogle) {
			try {
				LoadingService.show();
				await Http.post('cancelSpecificationSoliserv', {
					CDITEMTRAB: param.row.CDITEMTRAB,
					NRSOLISERV: this.nrsoliserv,
					ID_GOOGLE: idGoogle,
				});
				delete this.indexGoogleDocsIds[namedoc];
				const gridItemTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
				gridItemTaskS.datasource.get();
				LoadingService.hide();
			} catch (e) {
				LoadingService.hide();
				DialogServiceCustom.showError(e);
			}
		} else {
			AlertServiceCustom.customErrorAlert(Messages.ERROR_FILE_TYPE);
		}
	}

	public async onMountedFormAddTaskSoli() {
		LoadingService.show();
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		const formAddCall = InstanceService.getInstanceZdForm('formAddTaskSoli');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		const rowDefaultTaskSoli = await Http.get('findDefaultTaskSoli', {
			params: {
				NRSOLISERV: this.nrsoliserv,
			},
		});
		LoadingService.hide();
		formAddCall.value.soliTaskSoliAdd = rowDefaultTaskSoli.data.NRSOLISERV;
		formAddCall.value.soliTaskSoliAdd = rowDefaultTaskSoli.data.DSSOLISERV;
		formAddCall.value.referenceTaskSoliAdd = rowDefaultTaskSoli.data.DSREFETAREFA;
		formAddCall.value.assuntoTaskSoliAdd = rowDefaultTaskSoli.data.CDASSUNTO;
		formAddCall.value.responsibleTaskSoliAdd = rowDefaultTaskSoli.data.CDOPERRESP;
		formAddCall.value.prioridadeTaskSoliAdd = rowDefaultTaskSoli.data.NRPRIOTAREFA;
		formAddCall.value.taskTypeAdd = rowDefaultTaskSoli.data.IDORIGTARE;
	}

	public closeAddModalTaskSolid() {
		this.modalAddTaskS.hide();
		this.modalAddTaskS?.destroy();
	}

	public closeEspecSoliModalTaskSolid() {
		this.beforeDeleteTaskSEspec();
	}

	public async rowClickGridTasksActivities(params:any) {
		LoadingService.show();
		try {
			const tabMainFormDemandManagement = { component: null };
			tabMainFormDemandManagement.component = Metadata.getInstance<any>('tabMainFormDemandManagement');
			const tabBudgetIssue = InstanceService.getInstanceTabs('tabBudgetIssue');
			const tab = tabBudgetIssue.tabs[tabBudgetIssue.activeTab];
			setTimeout(async () => {
				if (tab.events && tab.events.change && typeof tab.events.change === 'function') {
					await tab.events.change(params);
				}
			}, 100);
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public async generateActivitiesTaskSoli() {
		const gridItemTaskS = InstanceService.getInstanceTekGrid('gridGenerateActivitiesItemTaskS');
		const gridProcess = InstanceService.getInstanceTekGrid('gridGenerateActivitiesProcessItemTaskS');
		const gridActivityS = InstanceService.getInstanceTekGrid('gridActivityS');
		const itemtarefas = gridItemTaskS.selectedRows;
		const processes = gridProcess.datasource.data;
		const nrtarefa = gridItemTaskS.datasource.filter.NRTAREFA;
		const cdarvprocess = gridProcess.datasource.filter.CDARVPROCESS;
		const nrsoliserv = gridProcess.datasource.filter.NRSOLISERV;
		try {
			if (itemtarefas.length === 0 || processes.length === 0) {
				throw new Error('É necessario Itens de trabalho e processos para gerar atividades');
			} else {
				const cdprocessos = processes.map((itemProcess) => (itemProcess.CDPROCESSO));
				const cditemtrabs = itemtarefas.map((tarefa) => (tarefa.CDITEMTRAB));
				const validateAtiv = await Http.get('findValidadeAtividateGerada', {
					params: {
						NRTAREFA: nrtarefa,
						CDPROCESSOS: cdprocessos,
						CDITEMTRABALHOS: cditemtrabs,
					},
				});
				if (validateAtiv.data && validateAtiv.data.length !== 0) {
					let message = 'Não é possivel gerar atividades por já estarem geradas para os itens de trabalho:<BR>';
					message += validateAtiv.data.map((valid:any) => (valid.NMITEMTRAB)).join(',<BR>');
					throw new Error(message);
				}

				LoadingService.show();
				await Http.post('generateActivitiesTaskSoli', {
					params: {
						NRTAREFA: nrtarefa,
						NRSOLISERV: nrsoliserv,
						CDARVPROCESS: cdarvprocess,
						PROCESSES: processes,
						ITEMTAREFAS: itemtarefas,
					},
				});
				LoadingService.hide();
				this.closeAddModalTaskSolid();
				gridActivityS.datasource.get();
			}
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showError(e);
		}
	}

	public onMountedFormAddItemTaskSoli() {
		const gridItemTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		const formAddCall = InstanceService.getInstanceZdForm('formAddItemTaskSoli');
		const selectTarefa = formAddCall.getChildInstance<Select>('taskSoliAdd');

		selectTarefa.datasource.filter.NRSOLISERV = gridItemTaskS.datasource.filter.NRSOLISERV;
		const nrtarefa = gridItemTaskS.datasource.filter?.NRTAREFA;
		formAddCall.value.soliTaskSoliAdd = gridItemTaskS.datasource.filter.NRSOLISERV;

		const { datasource } = gridTaskS;
		const { data } = datasource;

		if (nrtarefa) {
			formAddCall.value.taskSoliAdd = nrtarefa;
		} else if (data && data.length === 1) {
			formAddCall.value.taskSoliAdd = data[0].NRTAREFA;
		}

		selectTarefa.datasource.get();
	}

	public onMountedGridTotalizedActivitySi() {
		const gridItemPriTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
		const gridTotalizedActivityS = InstanceService.getInstanceTekGrid('gridTotalizedActivityS');

		gridTotalizedActivityS.datasource.filter.NRTAREFA = gridItemPriTaskS.datasource.filter.NRTAREFA;
		gridTotalizedActivityS.datasource.get();
	}

	public async onMountedFormGenerateActivitiesTaskSoli() {
		const gridItemPriTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
		const gridItemTaskS = InstanceService.getInstanceTekGrid('gridGenerateActivitiesItemTaskS');
		gridItemTaskS.datasource.filter.NRSOLISERV = gridItemPriTaskS.datasource.filter.NRSOLISERV;
		gridItemTaskS.datasource.filter.NRTAREFA = gridItemPriTaskS.datasource.filter.NRTAREFA;

		await gridItemTaskS.datasource.get();
		gridItemTaskS.selectedRows = gridItemTaskS.datasource.data;
	}

	public async saveGridTaskSGridS(param: any) {
		param.event.preventDefault();
		const rows = param.component.getEditedRows().map((row: any) => (
				{
					NRSOLISERV: row.NRSOLISERV,
					DSREFETAREFA: row.DSREFETAREFA,
					CDASSUNTO: row.CDASSUNTO,
					CDOPERRESP: row.CDOPERRESP,
					NRPRIOTAREFA: row.NRPRIOTAREFA,
					IDORIGTARE: row.IDORIGTARE,
					NRTAREFA: row.NRTAREFA,
				}
			));

		await Http.post('/editTarefaSoli', { rowsSave: rows });
		param.component.editing = false;
		param.component.editedRows = {};
		param.component.reload();
	}

	public async saveGridActivityS(param: any) {
		param.event.preventDefault();
		const rows = param.component.getEditedRows().map((row: any) => (
				{
					CDFILIAL: row.CDFILIAL,
					NRTAREFA: row.NRTAREFA,
					NRPLATIVTARE: row.NRPLATIVTARE,
					NRPRIOATIVTR: row.NRPRIOATIVTR,
					CDOPERRESP: row.CDOPERRESP,
					QTHRINFATIVTAR: row.QTHRINFATIVTAR,
				}
			));

		await Http.post('/editGridActivityS', { rowsSave: rows });
		param.component.editing = false;
		param.component.editedRows = {};
		param.component.reload();
	}

	public async saveGridItemTaskSGridS(param: any) {
		param.event.preventDefault();
		const rows = param.component.getEditedRows().map((row: any) => (
			{
				...row,
			}
		));
		await Http.post('/editItemTarefaSoli', { rowsSave: rows });
		param.component.editing = false;
		param.component.editedRows = {};
		param.component.reload();
	}

	public async changeFormGenerateActivitiesTaskSoliNrTarefa() {
		const generateActivitiesAddTaskSoli = InstanceService.getInstanceZdForm('generateActivitiesAddTaskSoli');
		const selectTarefa = generateActivitiesAddTaskSoli.getChildInstance<Select>('nrtarefaenerateActivitiesAddTaskSoli');
		const gridItemTaskS = InstanceService.getInstanceTekGrid('gridGenerateActivitiesItemTaskS');
		const nrtarefa = generateActivitiesAddTaskSoli.value.nrtarefaenerateActivitiesAddTaskSoli;

		gridItemTaskS.datasource.filter.NRSOLISERV = selectTarefa.datasource.filter.NRSOLISERV;
		gridItemTaskS.datasource.filter.NRTAREFA = [nrtarefa];
		gridItemTaskS.selectedRows = [];
		await gridItemTaskS.datasource.get();
		gridItemTaskS.selectedRows = gridItemTaskS.datasource.data;
	}

	public async changeFormGenerateActivitiesCdarvprocessTaskSoliNrTarefa() {
		const generateActivitiesAddTaskSoli = InstanceService.getInstanceZdForm('generateActivitiesAddTaskSoli');
		const gridActivitiesItemTaskS = InstanceService.getInstanceTekGrid('gridGenerateActivitiesProcessItemTaskS');
		const cdarvprocess = generateActivitiesAddTaskSoli.value.cdarvprocessGenerateActivitiesAddTaskSoli;

		gridActivitiesItemTaskS.datasource.filter.CDARVPROCESS = cdarvprocess;

		await gridActivitiesItemTaskS.datasource.get();
	}

	public closeAddModalItemTaskSolid() {
		this.modalAddTaskS.hide();
		this.modalAddTaskS?.destroy();
	}

	public async saveAddNewItemTaskSoli() {
		LoadingService.show();
		try {
			const formAddCall = InstanceService.getInstanceZdForm('formAddItemTaskSoli');
			const valid = formAddCall.validate();
			if (!valid) {
				DialogServiceCustom.messageErrorValidate();
			} else {
				const row = {
					NRSOLISERV: formAddCall.value.soliTaskSoliAdd,
					NRTAREFA: formAddCall.value.taskSoliAdd,
					CDITEMTRAB: formAddCall.value.cdItemTaskSoliAdd,
					NRPRIOITTARE: formAddCall.value.nrprioittareItemTaskSoliAdd,
					NRCPLXIMPLEM: formAddCall.value.nrcplximplemItemTaskSoliAdd,
					NRCPLXITEMTB: formAddCall.value.nrcplxitemtbItemTaskSoliAdd,
				};
				await Http.post('saveItemTarefaSoli', {
					rowsSave: [row],
				});
				this.closeAddModalItemTaskSolid();
				const gridTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
				gridTaskS.datasource.get();
			}
			LoadingService.hide();
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public async saveAddNewTaskSoli() {
		LoadingService.show();
		const formAddCall = InstanceService.getInstanceZdForm('formAddTaskSoli');
		const row = {
				NRSOLISERV: formAddCall.value.soliTaskSoliAdd,
				DSREFETAREFA: formAddCall.value.referenceTaskSoliAdd,
				CDASSUNTO: formAddCall.value.assuntoTaskSoliAdd,
				CDOPERRESP: formAddCall.value.responsibleTaskSoliAdd,
				NRPRIOTAREFA: formAddCall.value.prioridadeTaskSoliAdd,
				IDORIGTARE: formAddCall.value.taskTypeAdd,
			};
		try {
			await Http.post('saveTarefaSoli', {
				rowsSave: [row],
			});
			this.closeAddModalTaskSolid();
			const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
			gridTaskS.datasource.get();
			LoadingService.hide();
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public async beforeDeleteGridTaskSGridS(params:any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: (() => {
						DialogService.hide();
						this.doDeleteTaskSGridS(params);
					}),
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async beforeDeleteGridActivityS(params:any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: (() => {
						DialogService.hide();
						this.doDeleteGridActivityS(params);
					}),
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async doDeleteGridActivityS(params: any) {
		LoadingService.show();
		try {
			await Http.post('deleteGridActivityS', { data: params.component.selectedRows });
			params.component.selectedRows = [];
			params.component.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public isVisibleButtonEditSpecificationTaskS(param: any) {
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		let validate = gridTaskS.datasource.currentRow.IS_ESPEC === 'S';
		if (validate) {
			const nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
			const namedoc = `${nrsoliserv}_${param.row.CDITEMTRAB}`;
			const idGoogle = this.indexGoogleDocsIds[namedoc];
			validate = !idGoogle;
		}
		return validate;
	}

	public isVisibleButtonSaveSpecificationTaskS(param: any) {
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		let validate = gridTaskS.datasource.currentRow.IS_ESPEC === 'S';
		if (validate) {
			const nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
			const namedoc = `${nrsoliserv}_${param.row.CDITEMTRAB}`;
			const idGoogle = this.indexGoogleDocsIds[namedoc];
			validate = !!idGoogle;
		}
		return validate;
	}

	public async popupFileSpecificationTaskS(param: any) {
		await this.editEspecSoli();
		this.baseUrl = Config.env.endPoint;
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		this.cditemtrab = param.row.CDITEMTRAB;
		this.nrTarefa = param.row.NRTAREFA;
		try {
			LoadingService.show();
			const response = await Http.post('editSpecificationSoliserv', {
				CDITEMTRAB: this.cditemtrab,
				NRSOLISERV: this.nrsoliserv,
			});
			LoadingService.hide();
			const urlDocGoogle = `${response.data.url}?usp=sharing&embedded=true`;
			const namedoc = `${this.nrsoliserv}_${this.cditemtrab}`;
			this.indexGoogleDocsIds[namedoc] = response.data.id;
			const formEditEspecSoli = InstanceService.getInstanceAny('formEditEspecSoli');
			formEditEspecSoli.element.src = urlDocGoogle;
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showError(e);
		}
	}

	public async clickActionGenerateBudgetItemTaskS() {
		this.baseUrl = Config.env.endPoint;
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		LoadingService.show();
		try {
			await Http.post('mergeFileSpecificationTaskS', {
				NRSOLISERV: this.nrsoliserv,
			});
			const downloadUri = `${this.baseUrl}/openPageRequisite?NRSOLISERV=${this.nrsoliserv}`;
			window.open(downloadUri);
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public async downloadFileSpecificationTaskS(param: any) {
		this.baseUrl = Config.env.endPoint;
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		this.cditemtrab = param.row.CDITEMTRAB;
		try {
			LoadingService.show();
			const response = await Http.post('editSpecificationSoliserv', {
				CDITEMTRAB: this.cditemtrab,
				NRSOLISERV: this.nrsoliserv,
			});
			LoadingService.hide();
			const urlDocGoogle = response.data.url;
			const namedoc = `${this.nrsoliserv}_${this.cditemtrab}`;
			this.indexGoogleDocsIds[namedoc] = response.data.id;
			const gridItemTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
			gridItemTaskS.datasource.get();
			window.open(urlDocGoogle);
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showError(e);
		}
	}

	public async insertFileSpecificationTaskS() {
		this.baseUrl = Config.env.endPoint;
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		const fromSpecification = InstanceService.getInstanceZdForm('formModalInsertFileSpecificationTaskS');
		const fileInputSpecification = fromSpecification.getChildInstance<ZdFileInput>('fileInputUploadFileSpecificationTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;

		if (fileInputSpecification.value && (fileInputSpecification.value.name.endsWith('.doc') || fileInputSpecification.value.name.endsWith('.docx'))) {
			FileUpload.buildFileSendObject(fileInputSpecification.value).then(async (file) => {
				LoadingService.show();
				try {
					await Http.post('insertFileSpecificationTaskS', {
						NRSOLISERV: this.nrsoliserv,
						CDITEMTRAB: this.cditemtrab,
						DOCUMENT: file,
					});
					AlertServiceCustom.defaultSaveSuccessAlert();
				} catch (e) {
					DialogServiceCustom.showErrorBackend(e);
				}
				LoadingService.hide();
				this.closeAddModalTaskSolid();
			});
		} else {
			AlertServiceCustom.customErrorAlert(Messages.ERROR_FILE_EXPECTED);
		}
	}

	public onMountedModalInsertFileSpecificationTaskS() {
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		const formInsertFile = InstanceService.getInstanceZdForm('formModalInsertFileSpecificationTaskS');
		formInsertFile.value.nrSoliTaskSoliAdd = gridTaskS.datasource.filter.NRSOLISERV;
	}

	public async doDeleteTaskSEspec() {
		LoadingService.show();
		const gridTaskS = InstanceService.getInstanceTekGrid('gridTaskS');
		this.nrsoliserv = gridTaskS.datasource.filter.NRSOLISERV;
		const namedoc = `${this.nrsoliserv}_${this.cditemtrab}`;
		const idGoogle = this.indexGoogleDocsIds[namedoc];
		if (idGoogle) {
			try {
				LoadingService.show();
				await Http.post('cancelSpecificationSoliserv', {
					CDITEMTRAB: this.cditemtrab,
					NRSOLISERV: this.nrsoliserv,
					ID_GOOGLE: idGoogle,
				});
				delete this.indexGoogleDocsIds[namedoc];
				this.modalAddTaskS.hide();
				this.modalAddTaskS?.destroy();
				LoadingService.hide();
			} catch (e) {
				LoadingService.hide();
				DialogServiceCustom.showError(e);
			}
		} else {
			LoadingService.hide();
			AlertServiceCustom.customErrorAlert(Messages.ERROR_FILE_TYPE);
		}
	}

	public async doDeleteTaskSGridS(params: any) {
		LoadingService.show();
		try {
			await Http.post('deleteTarefasSoli', { data: params.component.selectedRows });
			params.component.selectedRows = [];
			params.component.datasource.get();
			this.selectedGridTaskSGridS(params);
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public async beforeDeleteTaskSEspec() {
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: (() => {
						DialogService.hide();
						this.doDeleteTaskSEspec();
					}),
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.CANCEL_DOCS, buttonYes);
	}

	public async beforeDeleteGridItemTaskSGridS(params:any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: (() => {
						DialogService.hide();
						this.doDeleteItemTaskSGridS(params);
					}),
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async doDeleteItemTaskSGridS(params: any) {
		LoadingService.show();
		try {
			await Http.post('deleteItemTarefasSoli', { data: params.component.selectedRows });
			params.component.selectedRows = [];
			params.component.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public selectedGridTaskSGridS(params: any) {
		const rows = params.component.selectedRows.map((row:any) => row.NRTAREFA);
		const gridItemTaskS = InstanceService.getInstanceTekGrid('gridItemTaskS');
		gridItemTaskS.datasource.filter.NRTAREFA = rows;
		gridItemTaskS.datasource.get();
	}

	public async clickActionGenerateActivities() {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/Task/Soli/tabTaskSoli/gridItemTaskS/modalGenerateActivitiesTaskS', true);
		this.modalAddTaskS.show();
	}

	public async clickActionGenerateTotalized() {
		this.modalAddTaskS = await ModalService.createFromJson('demandManagement/Task/Soli/tabTaskSoli/gridActivityS/modalTotalizedActivitiesTaskS', true);
		this.modalAddTaskS.show();
	}
}
