import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { InstanceService } from '@/services/InstanceService';
import { Utilities } from '@/services/Utilities';
import { LoadingService, Modal, ModalService } from '@zeedhi/common';
import { Http } from '@zeedhi/core';

export class WorkItemController {
    private lvlPattern: any;

    private lastLvl: any;

    private addModal!: Modal;

    public isEditing: boolean = false;

    get isNotEditing() {
        return !this.isEditing;
    }

    public treeGridInlineEdit() {
        this.isEditing = InstanceService.getInstanceTreeGridEditable('workitem-grid').editing;
    }

    public treeGridSaveEditing() {
        this.isEditing = InstanceService.getInstanceTreeGridEditable('workitem-grid').editing;
    }

    public cancelEditing() {
        InstanceService.getInstanceTreeGridEditable('workitem-grid').cancelEditedRows();
        this.isEditing = false;
    }

    public reloadGrid() {
        const grid = InstanceService.getInstanceTreeGridEditable('workitem-grid');
        grid.datasource.clearFilter();
        grid.reload();
    }

    public async openAddModal() {
        this.addModal = await ModalService.createFromJsonPost('', { jsonPath: 'workItem/addModal' });
        this.addModal.show();
    }

    public closeAddModal() {
        this.addModal.hide();
        this.addModal?.destroy();
    }

    public async storeLevelPattern() {
        this.lvlPattern = await Http.get('/workitem/levelpattern');
        this.lastLvl = this.lvlPattern.data[this.lvlPattern.data.length - 1].NIVEL;
    }

    public async verifyMasterItemSelected() {
        const parentField = InstanceService.getInstanceSelectTree('CDPARENT_ITTRAB');
        const grid = InstanceService.getInstanceTreeGridEditable('workitem-grid');
        const row = grid.datasource.currentRow;
        await parentField.datasource?.get();
        if (row.CDITEMTRAB && row.CDNVITEMTRAB < this.lastLvl) {
            parentField.setValue(row.CDITEMTRAB);
        }
    }

    public setMasterItemInfo() {
        const parentField = InstanceService.getInstanceSelectTree('CDPARENT_ITTRAB');
        const codeField = InstanceService.getInstanceTextInput('CDARVITTRAB');

        let newLvl = 1;
        if (parentField.value) {
            newLvl = parseInt(parentField.value.CDNVITEMTRAB, 10) + 1;
        }
        codeField.value = '';

        const newLvlConfig = this.lvlPattern.data.filter((pattern: any) => parseInt(pattern.NIVEL, 10) === newLvl)[0];
        codeField.addValidation('minLength', { limit: newLvlConfig.TAMANHO_NIVEL });
        codeField.addValidation('maxLength', { limit: newLvlConfig.TAMANHO_NIVEL });
        codeField.maxLength = newLvlConfig.TAMANHO_NIVEL;
    }

    public addModalChangeCdarvittrab() {
        const field = InstanceService.getInstanceTextInput('CDARVITTRAB');
        if (field.value && typeof field.value === 'string') {
            field.value = field.value.toUpperCase();
        }
    }

    public async saveAddModal() {
        Utilities.genericAddModalTekGrid('workitem-add-form', this.addModal, '/workitem/insert', 'workitem-grid', true);
    }

    public async saveEditing() {
        const grid = InstanceService.getInstanceTreeGridEditable('workitem-grid');
        try {
            LoadingService.show();
            await Http.post('/workitem/update', grid.getEditedRows());
            LoadingService.hide();
            AlertServiceCustom.defaultSaveSuccessAlert();
            this.isEditing = false;
            grid.cancelEditedRows();
            grid.datasource.clearFilter();
            grid.datasource.get();
        } catch (e) {
            LoadingService.hide();
            DialogServiceCustom.showErrorBackend(e);
        }
    }

    public getColumnStyle(params: any) {
        return params.row.IDATIVO === 'N' ? 'pm-grid-column-inactive' : '';
    }
}
